<?php

/**
 * Gestion de l'action pour peupler avec des COG
 *
 * @plugin Subdivisions
 **/

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Action pour peupler la base de données 
 * des codes COG, créé par l'INSEE, propre à la France.
 * La table d'accueil est spip_subdivisions_codes_specifiques.
 * Un lien est établit entre id_subdivision_code_specifique et id_subdivision 
 * avec la table de lien spip_subdivisions_codes_specifiques_liens.
 * Code officiel géographique (COG)
 * L'action ne prend en charge que le COG REG et les COG DEP
 * REG - Code région
 * Code de la région sur 2 positions.
 * DEP - Code département
 * Il est sur 3 positions afin de prendre en compte les départements des DOM.
 * COM - Code commune
 * Code de la commune sur 3 positions. Quand il est précédé du code DEP, il forme le code Insee de la commune.
 * AR - Code arrondissement
 * Code de l'arrondissement dans le département.
 * CT - Code canton
 * cas des communes découpées en cantons *
 * Les arguments attendus 
 *
 * @param string $arg
 *	cog
 *		confirmation de l'opération souhaitée	
 *		
 * @return void
 */

 
function action_subdivisions_peupler_cogs_dist ($arg = null) {
	if (is_null($arg)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arg = $securiser_action();
	}

	// acquision des arguments
	$arg = explode("-", $arg);
	list($etiquette_code) = $arg;
	$etiquette_code = strtoupper($etiquette_code);
	
	// vérifications de la validité des arguments
	if ($etiquette_code <> "COG") {
		return;
	}
		
	if (in_array($etiquette_code, array('COG', 'COG_REG'))) {
		$url ='https://geo.api.gouv.fr/regions';
		$appel = peuplement_cog($url,'COG_REG');
	}
	if (in_array($etiquette_code, array('COG', 'COG_DEP'))) {
		$url ='https://geo.api.gouv.fr/departements';
		$appel = peuplement_cog($url,'COG_DEP');
	}
}

function peuplement_cog($url, $etiquette_code) {
	// chargement des codes INSEE COG (retour : json)
	include_spip('inc/distant');
	$json = recuperer_page($url);

	// Préparation des informations à l'analyse (retour : array)
	$tableau = json_decode($json, true); 
	unset($json);

	// analyse des données
	foreach ($tableau as $element) {
		if ($etiquette_code == 'COG_REG') {
			// recherche d'une subdivision pouvant accueillir le code COG REGion
			$where = array (
				"iso_moi LIKE 'FR-___'",
				"titre LIKE " . sql_quote("%" . $element['nom'] . "%")
			);
		}
		if ($etiquette_code == 'COG_DEP') {
			// recherche d'une subdivision pouvant accueillir le code COG DEPartement
			$where = array (
				//'iso_parent != "" AND iso_moi NOT IN ("FR-PM","FR-BL","FR-MF","FR-PF","FR-CP")',
				//"titre LIKE " . sql_quote("%" . $element['nom'] . "%"),
				'iso_moi = "FR-'.$element['code'].'"'
			);
			// Les 5 départements d'Outre-mer
			switch ($element['nom']) {
 			case 'Guadeloupe':
				$where = array ('iso_moi = "FR-GP"');
				break;
			case 'Martinique':
				$where = array ('iso_moi = "FR-MQ"');
				break;
			case 'Guyane':
				$where = array ('iso_moi = "FR-GF"');
				break;
			case 'La Réunion':
				$where = array ('iso_moi = "FR-RE"');
				break;
			case 'Mayotte':
				$where = array ('iso_moi = "FR-YT"');
			break;
			}
		}
		$subdivision = sql_fetsel("id_subdivision,titre", "spip_subdivisions", $where);
		$id_subdivision = $subdivision['id_subdivision'];
		$titre = $subdivision['titre'];
		if ($id_subdivision) {
			// On a une subdivision qui peut accueillir le COG.
			// L'accueille-t-elle déjà ?
			$deja_la = sql_fetsel(
				"c.code_specifique,c.id_subdivision_code_specifique",
				"spip_subdivisions_codes_specifiques_liens AS l 
					LEFT JOIN (spip_subdivisions_codes_specifiques AS c)
					ON (l.id_subdivision_code_specifique=c.id_subdivision_code_specifique)",
				array(
					'l.objet=' . sql_quote('subdivision'),
					'l.id_objet=' . intval($id_subdivision),
					'l.role=' . sql_quote($etiquette_code)
				)
			);
			// S'il y a déjà un code on vérifie simplement s'il doit être mis à jour.
			if ($deja_la AND ($deja_la['code_specifique'] <> $element['code'])) {
				$champs = array (
					'id_subdivision_code_specifique' => '',
					'code_specifique' => $element['code'], 
					'etiquette_code' => '', 
					'titre' => '',
					'date' => date('Y-m-d H:i:s'),
					'statut' => "publie",
					'maj' => date('Y-m-d H:i:s')
				);
				include_spip('action/editer_objet');
				$erreurs = objet_modifier('subdivision_code_specifique',
					intval($deja_la['id_subdivision_code_specifique']),
					$champs
				);
				// La fonction retourne l’erreur en cas d’échec
				if ($erreurs) {
					$log = _T('subdivisions_log:action_cog_maj_erreur', array (
						'err' => print_r($erreurs,true),
						'antc' => $deja_la['code_specifique'],
						'nvc' => $element['code'],
						'id' => $deja_la['id_subdivision_code_specifique'])
					);
					spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
				} else { // ou une chaîne vide si tout s’est bien passé 
					$log = _T('subdivisions_log:action_cog_maj_oui', array (
						'antc' => $deja_la['code_specifique'],
						'nvc' => $element['code'],
						'id' => $deja_la['id_subdivision_code_specifique'])
					);
					spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
				}
			} 
			// S'il y a pas de code, il doit être créé et la liaison faite
			if (!$deja_la) {
				$champs = array (
					'id_subdivision_code_specifique' => '',
					'code_specifique' => $element['code'], 
					'etiquette_code' =>  $etiquette_code, 
					'titre' => $titre, // on place le même titre que la subdivision
					'date' => date('Y-m-d H:i:s'),
					'statut' => "publie",
					'maj' => ''
				);
			
				// création de l'objet subdivision_code_specifique
				include_spip('action/editer_objet');
				$id_subdivision_code_specifique = objet_inserer('subdivision_code_specifique', '', $champs);
				if ($id_subdivision_code_specifique) {
					$log = _T('subdivisions_log:action_cog_cree_oui', array (
						'nvc' => $element['code'],
						'nvn' => $element['nom'],
						'id' => $id_subdivision,
						'idcode' => $id_subdivision_code_specifique)
					);
					spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
					// création de l'association de l'objet subdivision_code_specifique avec l'objet subdivision
					include_spip('action/editer_liens');
					$erreurs = objet_associer(
						array("subdivision_code_specifique" => $id_subdivision_code_specifique),
						array("subdivision" => $id_subdivision),
						array("role" => $etiquette_code)
					);
					// retourne false s'il y a un problème ou un tableau si tout va bien.
					if (!$erreur) {
						$log = _T('subdivisions_log:action_cog_associe_oui', array (
							'id' => $id_subdivision_code_specifique)
						);
						spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
					} else {
						$log = _T('subdivisions_log:action_cog_associe_erreur', array (
							'id' => $id_subdivision,
							'id_cod' => $id_subdivision_code_specifique)
						);
						spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
					}
			
				} else {
					// l'objet subdivision_code_specifique n'a pas pu être créé, ce qui est étrange, et on le signale
					$log = _T('subdivisions_log:action_cog_cree_erreur', array (
						'nvc' => $element['code'],
						'nvn' => $element['nom'],
						'id' => $id_subdivision)
					);
					spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
				}
			}			
		} else {
			// pas de subdivision pour accueillir le code. On le signale.
				$log = _T('subdivisions_log:action_cog_maj_non', array (
					'nvc' => $element['code'],
					'nvn' => $element['nom'])
				);
				spip_log($log, 'subdivisions.' . _LOG_INFO_IMPORTANTE);
		}
	} // fin de l'analyse (foreach sur le requete API)
}