<?php
#
# Ces fichiers sont a placer dans le repertoire base/ de votre plugin
#
/**
 * Gestion de l'importation de `spip_subdivisions`
**/

/**
 * Fonction d'import de la table `spip_subdivisions`
 * à utiliser dans le fichier d'administration du plugin
 *
 *     ```
 *     include_spip('base/importer_spip_subdivisions');
 *     $maj['create'][] = array('importer_spip_subdivisions');
 *     ```
 *
**/
function importer_spip_subdivisions() {
	######## VERIFIEZ LE NOM DE LA TABLE D'INSERTION ###########
	$table = 'spip_subdivisions';

	// nom_du_champ_source => nom_du_champ_destination
	// mettre vide la destination ou supprimer la ligne permet de ne pas importer la colonne.

	$correspondances = array(
		'code_3166_2' => 'iso_moi',
		'country' => 'iso_pays',
		'parent' => 'iso_parent',
		'label'	=> 'titre',
		'maj' => 'date'
	);

	// transposer les donnees dans la nouvelle structure
	$inserts = array();
	list($cles, $valeurs) = donnees_spip_subdivisions();

	// on remet les noms des cles dans le tableau de valeur
	// en s'assurant de leur correspondance au passage
	if (is_array($valeurs)) {
		foreach ($valeurs as $v) {
			$i = array();
			foreach ($v as $cle => $valeur) {
				if (isset($correspondances[$cle]) and $correspondances[$cle]) {
						$i[ $correspondances[$cle] ] = $valeur;
				}
			}
			$i['nom_usage'] = "";
			// on ajoute une information : le nom commercial de la PACA
			if ($i['iso_moi'] == 'FR-PAC') {
				$i['nom_usage'] = '<multi>[fr]Région Sud[en]Région Sud</multi>';
				$i['titre'] = "<multi>[fr]Provence-Alpes-Côte d'Azur[en]Provence-Alpes-Côte d'Azur[de]Provence-Alpes-Côte d’Azur[it]Provenza-Alpi-Costa Azzurra[pt]Provença-Alpes-Costa Azul</multi>";
			}
			// on ajoute une information : le nom simple de la Région Pays de la Loire
			if ($i['iso_moi'] == 'FR-PDL') {
				$i['nom_usage'] = '<multi>[fr]Les Pays de la Loire</multi>';
			}			
			// on ajoute des informations propre à l'objet éditorial
			$i['statut'] = 'publie';
			$inserts[] = $i;
		}
		unset($valeurs);

		// inserer les donnees en base.
		$nb_inseres = 0;
		// ne pas reimporter ceux deja la (en cas de timeout)
		$nb_deja_la = sql_countsel($table);
		$inserts = array_slice($inserts, $nb_deja_la);
		$nb_a_inserer = count($inserts);
		// on decoupe en petit bout (pour reprise sur timeout)
		$inserts = array_chunk($inserts, 100);
		foreach ($inserts as $i) {
			sql_insertq_multi($table, $i);
			$nb_inseres += count($i);
			// serie_alter() relancera la fonction jusqu'a ce que l'on sorte sans timeout.
			if (time() >= _TIME_OUT) {
				// on ecrit un gentil message pour suivre l'avancement.
				echo "<br />Insertion dans $table relanc&eacute;e : ";
				echo "<br />- $nb_deja_la &eacute;taient d&eacute;j&agrave; l&agrave;";
				echo "<br />- $nb_inseres ont &eacute;t&eacute; ins&eacute;r&eacute;s.";
				$a_faire = $nb_a_inserer - $nb_inseres;
				echo "<br />- $a_faire &agrave; faire.";
				return;
			}
		}
	}
}


/**
 * Donnees de la table spip_subdivisions
 *
 * La table spip_iso3166subdivisions
 *
**/

function donnees_spip_subdivisions() {

	$table = "iso3166subdivisions";
	$nombre = sql_countsel("spip_".$table);
	if (!$nombre) { // la table n'est pas peuplée, il faut la peupler.
		// utilisation de l'API du Plugin Nomenclatures
		include_spip('isocode_fonctions');
		$resultat = array();
		$resultat = isocode_charger_tables($table);
		if (!$resultat['ok']) { // on a un problème, il faut donc le tracer dans un log
			spip_log(_T('subdivision:log_peupler_iso3166', array(
					'table' => $table,
					'aut' => $GLOBALS['auteur_session']['id_auteur'],
					'err' => print_r($resultat,true)
					)
				), 'subdivisions.' . _LOG_INFO_IMPORTANTE
			);
		}
	}
	$cles = array('code_3166_2', 'code_specific', 'country', 'type', 'parent', 'label', 'maj');
	$valeurs = sql_allfetsel(implode("," , $cles), "spip_" . $table);

	// il faudrait que l'API permette de versionner le paquet de données qui sert au peuplement. A défaut,
	// au jour d'aujourd'hui on sait qu'il manque 2 régions et leurs codes iso que l'on rajoute 
	// à la fin trop brutalement pour que ce plugin ne soit pas en version test.

	// a défaut de versionnage du paquet de donnée on utilise le versionnage de Nomenclatures officielles 0.4.3
	
	if ($GLOBALS['meta']['isocode_base_version'] == 1) {
		$valeurs[] = array( // Martinique
			'code_3166_2' => 'FR-MTQ',
			'code_specific' => '2',
			'country' => 'FR',
			'type' => 'overseas_region', 
			'parent' => '',
			'label' => '<multi>[fr]Martinique[en]Martinique[de]Martinique[it]Martinica[pt]Martinica</multi>',
			'maj' => ''
		);
	
		$valeurs[] = array( 
			'code_3166_2' => 'FR-GUF', 
			'code_specific' => '3',
			'country' => 'FR', 
			'type' => 'overseas_region',	
			'parent' => '', 
			'label' => '<multi>[fr]Guyane[en]French Guiana[de]Französisch-Guayana[it]Guyana francese[pt]Guiana Francesa</multi>', 
			'maj' => ''
		);
	
	// Les régions étant absentes, les départements n'en font pas mention comme parent
	// il faut donc aussi corriger ce point dans le tableau multidimentionnel :

		foreach ($valeurs as $key => $value) {
			if ($value['code_3166_2'] == 'FR-MQ') {
				$valeurs[$key]['parent'] = 'FR-MTQ';
			}
			if ($value['code_3166_2'] == 'FR-GF') {
				$valeurs[$key]['parent'] = 'FR-GUF';
			}
	// on en profite pour retirer des explications entre parenthèses qui n'ont rien à faire dans des titres
			$valeurs[$key]['label'] = trim(preg_replace('#[\(].*?[\)]#', '', $value['label']));
	// et pour corriger la graphie erronée de Grand Est qui ne prend pas de trait d'union
			if ($value['code_3166_2'] == 'FR-GES') {
				$valeurs[$key]['label'] = '<multi>[fr]Grand Est</multi>';
			}
	// et pour corriger la graphie erronée de Pays de la Loire qui ne prend pas non plus de traits d'union
			if ($value['code_3166_2'] == 'FR-PDL') {
				$valeurs[$key]['label'] = '<multi>[fr]Pays de la Loire</multi>';
			}
		}
	}


	return array($cles, $valeurs);
}


