<?php
/**
 * Gestion du formulaire de d'édition d'un code spécifique (objet subdivision_code_specifique)
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Formulaires
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');


function etablir_liste_etiquettes(){
	return sql_allfetsel('etiquette_code', 
						 'spip_subdivisions_codes_specifiques', 
						 'etiquette_code != ""',
						 'etiquette_code');
}
/**
 * Un simple formulaire de déclaration des saisies
 *
 * Utilisation du plugin Saisies
 *
 * @return array
 *     tableau décrivant les saisies à afficher dans le formulaire de configuration
 **/
 
function formulaires_subdivision_code_specifique_saisies($type_edition='', $type_icone='', $icone_objet = '',$liste_etiquette_code =''){
	$saisies = array(
		array( // le fieldset principal
			'saisie' => 'fieldset',
			'options' => array(
				'nom' => 'le_code_specifique',
				'label' => $type_edition,
				'icone' => $type_icone,
			),
    		'saisies' => array( // les champs dans le fieldset 
				array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'id_subdivision_code_specifique'
					)
				),
				array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'retour',
					)
				),
				array( // A-t-on demandé que cette subdivision soit associée à un objet (lors de sa création) ?
					'saisie' => 'hidden',
					'options' => array(
						'nom' => 'associer_objet'
					)
				),
				array( 
					'saisie' => 'input',
					'options' => array(
						'nom' => 'code_specifique',
						'label' => _T('subdivision_code_specifique:label_code_specifique'),
						'obligatoire' => 'oui',
 					)
				),
				array( 
					'saisie' => 'textarea',
					'options' => array(
						'nom' => 'titre',
						'label' => _T('subdivision_code_specifique:label_titre'),
						'obligatoire' => 'oui',
 						'placeholder' => '&lt;multi&gt;[fr]en français[en]in english</multi>',
						'conteneur_class' => 'pleine_largeur'
					)
				),
				array( 
					'saisie' => 'selection',
					'options' => array(
						'nom' => 'etiquette_code',
						'label' => _T('subdivision_code_specifique:label_etiquette_code'),
						'explication' => _T('subdivision_code_specifique:label_etiquette_code_explication'),
						'data' => $liste_etiquette_code
					)
				),
			)
		),
		array( // le fieldset d'association 
			'saisie' => 'fieldset',
			'options' => array(
				'afficher_si'=> '@associer_objet@ != ""',
				'nom' => 'lassociation',
				'label' => _T('subdivision_code_specifique:label_lassociation'),
				'icone' => $icone_objet
			),
			'saisies' => array( // les champs dans le second fieldset 
				array(
					'saisie' => 'case',
					'options' => array(
						'nom' => 'c_associe',
						'label_case' => _T('subdivision_code_specifique:texte_associer_code_specifique'),
						'conteneur_class' => 'pleine_largeur'
					)
				)
			)
		)
	);

	return $saisies;
}

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet édité
 *
 * @param int|string $id_subdivision_code_specifique
 *     Identifiant du code spécifique. 'new' pour un nouveau code.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return string
 *     Hash du formulaire
 */
function formulaires_editer_subdivision_specifique_identifier_dist($id_subdivision_code_specifique = 'new', $id_pays = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	return serialize(array(intval($id_subdivision_code_specifique), $associer_objet));
}

/**
 * Chargement du formulaire d'édition de subdivision_specifique
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @uses formulaires_editer_objet_charger()
 *
 * @param int|string $id_subdivision_code_specifique
 *     Identifiant du code spécifique. 'new' pour un nouveau code.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Environnement du formulaire
 */
function formulaires_editer_subdivision_code_specifique_charger_dist($id_subdivision_code_specifique = 'new', $id_parent = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$valeurs = formulaires_editer_objet_charger('subdivision_code_specifique', $id_subdivision_code_specifique, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	$type_icone = "subdivision_code_specifique-edit-16.png";
	$type_edition = _T('subdivision_code_specifique:icone_modifier_subdivision_code_specifique');

	if ($valeurs['id_subdivision'] == 'oui') {
		$type_icone = "subdivision_code_specifique-new-16.png";
		$type_edition = _T('subdivision_code_specifique:icone_creer_subdivision_code_specifique');
	}
	$valeurs['retour'] = $retour;

	$liste_etiquette_code = etablir_liste_etiquettes();

	// A-t-on demandé à ce que la subdivision soit associée à un objet éditorial ?
	if ($associer_objet) {
		$valeurs['associer_objet'] = $associer_objet;
		list($objet, $id_objet) = explode('|', $associer_objet);
		$icone_objet = chemin_image($objet);
		$valeurs['c_associe'] = 'on';
		$type_icone = "subdivision_code_specifique-new-link-16.png";
		$type_edition = _T('subdivision_code_specifique:texte_creer_associer_subdivision_code_specifique');
	} else
		$valeurs['c_associe'] = '';

	// transmettre les listes au plugin Saisies pour formulaires

	$valeurs['_mes_saisies'] = formulaires_subdivision_code_specifique_saisies($type_edition, $type_icone, $icone_objet,$liste_etiquette_code);
	
	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition d'un code spécifique (objet subdivision_code_specifique)
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @uses formulaires_editer_objet_verifier()
 *
 * @param int|string $id_subdivision_code_specifique
 *     Identifiant du code spécifique. 'new' pour un nouveau code.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Tableau des erreurs
 */
function formulaires_editer_subdivision_code_specifique_verifier_dist($id_subdivision_code_specifique = 'new', $id_parent = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	$erreurs = array();

	//$erreurs = formulaires_editer_objet_verifier('subdivision_code_specifique', $id_subdivision_code_specifique, array('id_subdivision_code_specifique', 'titre'));

	return $erreurs;
}

/**
 * Traitement du formulaire d'édition d'un code spécifique (objet subdivision_code_specifique)
 *
 * Traiter les champs postés
 *
 * @uses formulaires_editer_objet_traiter()
 *
 * @param int|string $id_subdivision_code_specifique
 *     Identifiant du code spécifique. 'new' pour un nouveau code.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Retours des traitements
 */
function formulaires_editer_subdivision_code_specifique_traiter_dist($id_subdivision_code_specifique = 'new', $id_parent = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	//if (_request('id_subdivision_code_specifique')==0) // vous pouvez indiquer que vous ne voulez pas que l'auteur soit lié à la région.
		//set_request('id_auteur','');   // objet_inserer va chercher l'information en un _request('id_auteur')
		//voir si on ne met pas une config pour cela.

	// rompre l'association si nécessaire		
	if (_request('c_associe')==''){
		set_request('associer_objet','');
	} else { // on garde la donnée de redirection s'il y a une association
		$redirect=_request('redirect');
	}

	$retours = formulaires_editer_objet_traiter('subdivision_code_specifique', $id_subdivision_code_specifique, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	// associer la subdivision_specifique à un objet
	if (_request('associer_objet') AND $id_subdivision_code_specifique = $retours['id_subdivision_code_specifique']) {			
		if (intval(_request('associer_objet'))) {
				// compat avec l'appel de la forme ajouter_id_article
				$objet = 'article';
				$id_objet = intval(_request('associer_objet'));
		} else {
				list($objet, $id_objet) = explode('|', _request('associer_objet'));
		}
		if ($objet and $id_objet and autoriser('modifier', $objet, $id_objet)) {
			include_spip('action/editer_liens');
			objet_associer( array('subdivision_code_specifique' => $id_subdivision_code_specifique), array($objet => $id_objet),array('role' => _request('etiquette_code')) );
			// rediriger vers l'objet
			if (isset($redirect)) {
				$retours['redirect'] = parametre_url($redirect, 'id_lien_ajoute', $id_subdivision_code_specifique, '&');
			}
			return $retours;
		}
		else
			return array('message_erreur'=>_T('subdivision_code_specifique:erreur_association'));
	} // si remord par rapport à l'association à l'objet, rediriger vers la subdivision
	elseif (_request('c_associe')=='non')
		$retours['redirect']=generer_url_ecrire('subdivision_code_specifique','id_subdivision_code_specifique='.$retours['id_subdivision_code_specifique']);
	
	
	return $retours;
}
