<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin Subdivisions Géographiques
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2019-2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Installation
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Fonction d'installation et de mise à jour du plugin Subdivisions Géographiques.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible
 *     Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 * @return void
**/
function subdivisions_upgrade($nom_meta_base_version, $version_cible) {
	$maj = array();

	include_spip('base/importer_spip_subdivisions');
	include_spip('base/importer_spip_subdivisions_apis');
	$maj['create'] = array(
		array('maj_tables', array('spip_subdivisions', 'spip_subdivisions_liens','spip_subdivisions_apis', 'spip_subdivisions_peuplements','spip_subdivisions_codes_specifiques', 'spip_subdivisions_codes_specifiques_liens')),
		array('importer_spip_subdivisions'),
		array('importer_spip_subdivisions_apis')
 	);

	// création de deux objets éditoriaux pour faire appel aux Opens Datas 
	// en vue d'apporter aux subdivisions des formes géométriques définissant leurs contours.
	
	$maj['1.0.1'] = array(
	    	array('maj_tables', array('spip_subdivisions_apis', 'spip_subdivisions_peuplements'))
    );

	// possibilité de créer et associer à l'infini des codes spécifiques,
	// suppression des champs transposables
	$maj['1.0.2'] = array(
	    	array('sql_alter', "TABLE spip_subdivisions DROP COLUMN specifique"),
	    	array('sql_alter', "TABLE spip_subdivisions DROP COLUMN nuts"),
	    	array('sql_alter', "TABLE spip_subdivisions DROP COLUMN nom_usage"),
	    	array('maj_tables', array('spip_subdivisions_specifiques', 'spip_subdivisions_specifiques_liens'))
    );

 	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);

}


/**
 * Fonction de désinstallation du plugin Subdivisions Géographiques.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @return void
**/
function subdivisions_vider_tables($nom_meta_base_version) {

	# Supression des tables
	sql_drop_table('spip_subdivisions');
	sql_drop_table('spip_subdivisions_liens');
	sql_drop_table('spip_subdivisions_apis');
	sql_drop_table('spip_subdivisions_peuplements');
	sql_drop_table('spip_subdivisions_codes_specifiques');
	sql_drop_table('spip_subdivisions_codes_specifiques_liens');

	# Suppression des liens marquant l'association des points (formes géométriques, ici) aux subdivisions
	sql_delete('spip_gis_liens', sql_in('objet', array('subdivision')));
	// on laisse les formes géométriques qui "appartiennent" maintenant à la bibliothèque d'objets de GIS

	# Nettoyer les versionnages
	sql_delete('spip_versions', sql_in('objet', array('subdivision')));
	sql_delete('spip_versions_fragments', sql_in('objet', array('subdivision')));

	effacer_meta($nom_meta_base_version);
}
