<?php
/**
 * Définit les pipelines utilisés par le plugin Subdivisions Géographiques
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Pipelines
 */

if (!defined("_ECRIRE_INC_VERSION")) return;


/**
 * Ajout de contenu sur les objets.
 * 
 * Contenus :
 * - formulaire de liaisons entre les auteurs et les subdivisions
 * - bouton de téléchargement des contours des subdivisions
 * - formulaire de liaisons entre les subdivisions et les objets reconnus dans sa configuration
 *
 * @pipeline affiche_milieu
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function subdivisions_affiche_milieu($flux) {
	$texte = '';
	$e = trouver_objet_exec($flux['args']['exec']);
	$table = table_objet_sql($flux['args']['exec']);

	// Pour les subdivisions...
	if (!$e['edition'] and in_array($e['type'], array('subdivision'))) {
		//... associer des auteurs (donnez des rôles aux auteurs vis-à-vis des subdivisions !)
		$texte .= recuperer_fond('prive/objets/editer/liens', array(
			'table_source' => 'auteurs',
			'objet' => $e['type'],
			'id_objet' => $flux['args'][$e['id_table_objet']],
	        'editable'=>autoriser('associerauteurs',$e['type'],$flux['args'][$e['id_table_objet']])?'oui':'non'
		));
		// ... créez des codes_specifiques à associer aux subdivisions 
		// (vos codes sur-mesure !)
		$texte .= recuperer_fond('prive/objets/editer/liens', array(
			'table_source' => 'subdivisions_codes_specifiques',
			'objet' => $e['type'],
			'id_objet' => $flux['args'][$e['id_table_objet']],
	        'editable'=>autoriser('associersubdivisions',$e['type'],$flux['args'][$e['id_table_objet']])?'oui':'non'
		));
		// ... télécharger des formes (Utiliser l'Open Data)
		if (test_plugin_actif('gisgeom')) {
			include_spip('inc/apigeo');
			// pas de forme installée et une API dispo : on propose l'installation !
			if (!$date_peuplement = apigeo_trouver_forme($flux['args'][$e['id_table_objet']]) AND
				$id_api = apigeo_trouver_api($flux['args'][$e['id_table_objet']]))
				{	
				$texte .= icone_verticale(
					_T('subdivision:donnees_installer_contour'),
					generer_action_auteur('subdivision_peupler', $flux['args'][$e['id_table_objet']] . "-definition", self()),
					'multipolygon-24.png',
					'new',
					'right'
				)
					. "<br class='nettoyeur' />";
			}

		}
	}
	
	// subdivisions associées aux objets éditoriaux sélectionnés dans la configuration du plugin 
	// ('régionaliser' vos objets !)
	if (!$e['edition'] and in_array($table, lire_config('subdivisions/association_subdivision_objets', array()))) {
		$texte .= recuperer_fond('prive/objets/editer/liens', array(
			'table_source' => 'subdivisions',
			'objet' => $e['type'],
			'id_objet' => $flux['args'][$e['id_table_objet']],
	        'editable'=>autoriser('associersubdivisions',$e['type'],$flux['args'][$e['id_table_objet']])?'oui':'non'
		));
	}


	if ($texte) {
		if ($p = strpos($flux['data'], '<!--affiche_milieu-->')) {
			$flux['data'] = substr_replace($flux['data'], $texte, $p, 0);
		} else {
			$flux['data'] .= $texte;
		}
	}

	return $flux;
}


/**
 * Ajouter les objets sur les vues des parents directs
 *
 * @pipeline affiche_enfants
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
**/
function subdivisions_affiche_enfants($flux) {
	if ($e = trouver_objet_exec($flux['args']['exec']) and $e['edition'] == false) {
		$id_objet = $flux['args']['id_objet'];
		if ($e['type'] == 'subdivision') {
		// à développer : une subdivision peut être le parent d'une autre subdivision
		}
	}
	return $flux;
}


/**
 * Ajout des informations sur les subdivisions dans la boite_info des pays
 *
 * @pipeline boite_infos
 * @param  string $flux
 * @return string
 */
function subdivisions_boite_infos($flux) {
	
	if (isset($flux['args']['type']) and isset($flux['args']['id']) and $id = intval($flux['args']['id'])) {
		$texte = '';
		if ($flux['args']['type'] == 'pays') {
		// Pays peut être simplement lié à la subdivisions 
		// où être rechercher dans ISO_parent ?
		}
	}
	
	return $flux;
}
?>